<!-- markdownlint-disable -->

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils`





---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L33"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `lonlat_lookup`

```python
lonlat_lookup(df_way, primary_data)
```

Lookup refs and convert to list of longlats 


---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L49"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `way_or_area`

```python
way_or_area(df_way)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L68"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `tags_melt`

```python
tags_melt(df_exp, nan_threshold=0.75)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L87"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `columns_melt`

```python
columns_melt(df_exp, columns_to_move)
```






---

<a href="https://github.com/pypsa-meets-earth/earth-osm/blob/main/earth_osm/utils.py#L117"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `tags_explode`

```python
tags_explode(df_melt)
```






